// Temporary proxy for letting existing code find bundled NL include files
// without changing it

#ifndef GEOGRAM_NL_MATRIX
#define GEOGRAM_NL_MATRIX

#ifdef __cplusplus
extern "C" {
#endif

#include <geogram/third_party/OpenNL/nl_matrix.h>

#ifdef __cplusplus
}
#endif

#endif
